qrcode-cli-0.2.0 is not a library.
A CLI I made while practicing rust to easily make QR codes with just one command, all in your terminal.

Install
&& &&
Usage
Parameters
data (d) * : String to be encoded in the QR code.
output (o) : Path to the output file - Defaults to qrcode.png.
A QR code will be generated with the given data and saved to the given output file.

Author
👤 Dhravya Shah
- Website: https://dhravya.dev
- Twitter: @dhravyashah
- Github: @dhravya
Show your support
Give a ⭐️ if this project helped you!
This README was generated with ❤️ by readme-md-generator